Graphical FrontEnd
==================
.. currentmodule:: pypec.Analyse_PEC
.. automodule:: pypec.Analyse_PEC
	:members:
	:undoc-members:

Iph Functions
==================
.. currentmodule:: pypec.iph_functions
.. automodule:: pypec.iph_functions
	:members:
	:undoc-members:

Parallel Processes
==================
.. currentmodule:: pypec.Parallel_Process
.. automodule:: pypec.Parallel_Process
	:members:
	:undoc-members: